=======
Credits
=======

Development Lead
----------------

* Rafal Gumienny <guma44@gmail.com>, <r.gumienny@unibas.ch>

Contributors
------------

* Simon van Heeringen <simon.vanheeringen@gmail.com>
* Tycho Bismeijer <tychobismeijer@gmail.com>
* Haries Ramdhani
* KwatME
* Rich Jones <miserlou@gmail.com>
* agalitsyna
